#ifndef GETC_C
#define GETC_C

/* Small c library, by Jeremy Dewey (jxd45@po.cwru.edu)
   http://www.seashellinc.com/~jdewey

   Synopsis:
      getc()

   Description:
      Waits for the user to press a key, returns the ASCII value of the key
      translated (i.e. pressing '5' returns 'R'). Also supports use of the 2nd
      and ALPHA keys, when GETC_CMP is defined to allow input of lowercase and
      numeric characters.

   Example: 
      #define GETC_CMP
      ...
      ch = getc()

   Notes:

*/

#include "key.h"

extern char key_up[0x39];
extern char key_lo[0x39];
extern char key_math[0x39];
extern char key_2nd[0x39];


char state, c;

//state = 0;

getc() {
   while (1) {
      c = getkey();
      if (c == K_ALPHA)
      {
         if (state == 1) state = 0;
         else state = 1;
      } else if (c == K_MATH)
      {
         if (state == 2) state = 0;
         else state = 2;
      } else if (c == K_2ND)
      {
         if (state == 3) state = 0;
         else state = 3;
      }
      else {
         if (state == 0) return key_lo[c];
         else if (state == 1) return key_up[c];
         else if (state == 2) return key_math[c];
         else return key_2nd[c];
      }
   }
}


getc_capps() {
   return key_up[getkey()];
}


#asm

key_up:
.db $00
.db $07,$08,$05,$06,$00,$00,$00,$00
.db $0d,$22,'W','R','M','H',$00,$00
.db '?',$5b,'V','Q','L','G',$00,$00
.db $00,'Z','U','P','K','F','C',$00
.db ' ','Y','T','O','J','E','B',$00
.db $00,'X','S','N','I','D','A',$00
.db $00,$00,$00,$00,$00
.db $00,$1b,$7f


key_lo:
.db $00
.db $07,$08,$05,$06,$00,$00,$00,$00
.db $0d,$22,'w','r','m','h',$00,$00
.db '?',$5b,'v','q','l','g',$00,$00
.db $00,'z','u','p','k','f','c',$00
.db ' ','y','t','o','j','e','b',$00
.db $00,'x','s','n','i','d','a',$00
.db $00,$00,$00,$00,$00
.db $00,$1b,$7f

key_math:
.db $00
.db $07,$08,$05,$06,$00,$00,$00,$00
.db $0d,'+','-','*','/','^',$00,$00
.db $1a,'3','6','9',')',$00,$00,$00
.db '.','2','5','8','(',$00,$00,$00
.db '0','1','4','7',',',$00,$00,$00
.db $00,$1c,$00,$00,$12,$11,$00,$00
.db $00,$00,$00,$00,$00
.db $00,$1b,$7f

key_2nd:
.db $00
.db $07,$08,$05,$06,$00,$00,$00,$00
.db $0d,$00,']',$c1,$00,$c4,$00,$00  
.db $00,$00,$00,$d7,'}',$00,$00,$00
.db ':',$00,$00,$00,'{',$00,$00,$00
.db $00,$00,$00,$00,$1b,$00,$00,$00
.db $00,$00,'e',$1d,$10,$00,$00,$00
.db $00,$00,$00,$00,$00
.db $00,$1b,$7f

#endasm


#endif /* GETC_H */
