#ifndef HVLINE_C
#define HVLINE_C

/* Small c library, by Jeremy Dewey (jxd45@po.cwru.edu)
   http://www.seashellinc.com/~jdewey

   Synopsis:
      hline(char x1, char x2, char y)
      vline(char y1, char y2, char x)

   Description:
      Draws a horizontal or vertical line

   Example:
      hline(0, 10, 5)
      vline(0, 10, 5)

   Notes:
      o The first parameter must be smaller than the second

*/

/*-----------------------------------------------------------------------
 *; purpose : Draws a horizontal line
 *; input   : c = y; d = x1 < e = x2   (0,0) is coord of lower left corner !!
 *; output  : line drawn in GRAPH_MEM
 *; author  : Wouter Demuynck (kadem@unicall.be)
 *------------------------------------------------------------------------ */

hline(x1, x2, y) char x1, x2, y; {
#asm
   ld  hl,2
   add hl,sp
   ld  c,(hl)           ;y 
   inc hl
   inc hl
   ld  e,(hl)           ;x2
   inc hl
   inc hl
   ld  d,(hl)           ;x1


 ld a,e
 sub d
 ld b,a
DrawHorLineLoop:
 push bc
 push de
 ld a,e
 sub b
 ld b,a
 call _putpix
 pop de
 pop bc
 djnz DrawHorLineLoop
#endasm
}

/* ----------------------------------------------------------------------
 *; purpose : Draws a vertical line
 *; input   : c = x; d = y1 < e = y2   (0,0) is coord of lower left corner !!
 *; output  : line drawn in GRAPH_MEM
 *; author  : Wouter Demuynck (kadem@unicall.be)
 * ======================================================================= */

vline(y1, y2, x) char y1, y2, x; {
#asm
DrawVerLine:

   ld  hl,2
   add hl,sp
   ld  c,(hl)           ;x 
   inc hl
   inc hl
   ld  e,(hl)           ;y2
   inc hl
   inc hl
   ld  d,(hl)           ;y1

 ld a,e
 sub d
 ld b,a                   ; loop e - d = y2 - y1 = delta y times
DrawVerLineLoop:
 push bc
 ld a,e
 sub b
 push bc ;* push bc
 ld c,a
 pop hl  ; get it back in HL 
 ld b,l
 push de
 call _putpix
 pop de
 pop bc
  djnz DrawVerLineLoop
#endasm
}

#endif
